
.. image:: molecular.svg
   :alt: molecular
   :height: 200

a package for molecular dynamics simulations and analysis

..
   master

.. image:: https://img.shields.io/pypi/v/molecular
   :target: https://pypi.org/project/molecular/

.. image:: https://img.shields.io/travis/com/lockhartlab/molecular/master
   :target: https://travis-ci.com/github/LockhartLab/molecular

.. image:: https://img.shields.io/codecov/c/github/lockhartlab/molecular/master
   :target: https://codecov.io/gh/LockhartLab/molecular

..
   *dev:*
   <nobr><img src="https://img.shields.io/travis/com/lockhartlab/molecular/dev"  alt="build-status-dev"/></nobr>
   <nobr><img src="https://img.shields.io/codecov/c/github/lockhartlab/molecular/dev" alt="coverage-dev"/></nobr>

note that this package is **still in development**
at this stage, I'm only building thing as they come to mind  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

Note: portions of this code have Fortran backends that may need to be built prior to successful use of the code. We
have it on our to-do list to compile OS-specific wheels.

yet, install simply by calling `pip install molecular` or `pip install --pre molecular` for the latest development
release.
